@@ -28,7 +28,7 @@
 
 (require 'custom)
 
-(defconst mime-user-interface-product ["SEMI" (1 14 2) "Daishji"]
+(defconst mime-user-interface-product ["SEMI" (1 14 3) "Ushinoya"]
   "Product name, version number and code name of MIME-kernel package.")
 
 (autoload 'mule-caesar-region "mule-caesar"
